# SquareConnect.CatalogObject

### Description

The wrapper object for the Catalog entries of a given object type.  The type of a particular `CatalogObject` is determined by the value of the `type` attribute and only the corresponding data attribute can be set on the `CatalogObject` instance. For example, the following list shows some instances of `CatalogObject` of a given `type` and their corresponding data atrribute that can be set: - For a `CatalogObject` of the `ITEM` type, set the `item_data` attribute to yield the `CatalogItem` object. - For a `CatalogObject` of the `ITEM_VARIATION` type, set the `item_variation_data` attribute to yield the `CatalogItemVariation` object. - For a `CatalogObject` of the `MODIFIER` type, set the `modifier_data` attribute to yield the `CatalogModifier` object. - For a `CatalogObject` of the `MODIFIER_LIST` type, set the `modifier_list_data` attribute to yield the `CatalogModifierList` object. - For a `CatalogObject` of the `CATEGORY` type, set the `category_data` attribute to yield the `CatalogCategory` object. - For a `CatalogObject` of the `DISCOUNT` type, set the `discount_data` attribute to yield the `CatalogDiscount` object. - For a `CatalogObject` of the `TAX` type, set the `tax_data` attribute to yield the `CatalogTax` object. - For a `CatalogObject` of the `IMAGE` type, set the `image_data` attribute to yield the `CatalogImageData`  object. - For a `CatalogObject` of the `QUICK_AMOUNTS_SETTINGS` type, set the `quick_amounts_settings_data` attribute to yield the `CatalogQuickAmountsSettings` object. - For a `CatalogObject` of the `PRICING_RULE` type, set the `pricing_rule_data` attribute to yield the `CatalogPricingRule` object. - For a `CatalogObject` of the `TIME_PERIOD` type, set the `time_period_data` attribute to yield the `CatalogTimePeriod` object. - For a `CatalogObject` of the `PRODUCT_SET` type, set the `product_set_data` attribute to yield the `CatalogProductSet`  object. - For a `CatalogObject` of the `SUBSCRIPTION_PLAN` type, set the `subscription_plan_data` attribute to yield the `CatalogSubscriptionPlan` object.   For a more detailed discussion of the Catalog data model, please see the [Design a Catalog](/catalog-api/design-a-catalog) guide.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **String** | The type of this object. Each object type has expected properties expressed in a structured format within its corresponding &#x60;*_data&#x60; field below. See [CatalogObjectType](#type-catalogobjecttype) for possible values | 
**id** | **String** | An identifier to reference this object in the catalog. When a new &#x60;CatalogObject&#x60; is inserted, the client should set the id to a temporary identifier starting with a \&quot;&#x60;#&#x60;\&quot; character. Other objects being inserted or updated within the same request may use this identifier to refer to the new object.  When the server receives the new object, it will supply a unique identifier that replaces the temporary identifier for all future references. | 
**updated_at** | **String** | Last modification [timestamp](https://developer.squareup.com/docs/build-basics/working-with-dates) in RFC 3339 format, e.g., &#x60;\&quot;2016-08-15T23:59:33.123Z\&quot;&#x60; would indicate the UTC time (denoted by &#x60;Z&#x60;) of August 15, 2016 at 23:59:33 and 123 milliseconds. | [optional] 
**version** | **Number** | The version of the object. When updating an object, the version supplied must match the version in the database, otherwise the write will be rejected as conflicting. | [optional] 
**is_deleted** | **Boolean** | If &#x60;true&#x60;, the object has been deleted from the database. Must be &#x60;false&#x60; for new objects being inserted. When deleted, the &#x60;updated_at&#x60; field will equal the deletion time. | [optional] 
**custom_attribute_values** | [**{String: CatalogCustomAttributeValue}**](CatalogCustomAttributeValue.md) | A map (key-value pairs) of application-defined custom attribute values. The value of a key-value pair is a &#x60;CatalogCustomAttributeValue&#x60; object. The key is the &#x60;key&#x60; attribute value defined in the associated &#x60;CatalogCustomAttributeDefinition&#x60; object defined by the application making the request.  If the &#x60;CatalogCustomAttributeDefinition&#x60; object is defined by another application, the &#x60;CatalogCustomAttributeDefinition&#x60;&#39;s key attribute value is prefixed by the defining application ID. For example, if the &#x60;CatalogCustomAttributeDefinition&#x60; has a &#x60;key&#x60; attribute of &#x60;\&quot;cocoa_brand\&quot;&#x60; and the defining application ID is &#x60;\&quot;abcd1234\&quot;&#x60;, the key in the map is &#x60;\&quot;abcd1234:cocoa_brand\&quot;&#x60; if the application making the request is different from the application defining the custom attribute definition. Otherwise, the key used in the map is simply &#x60;\&quot;cocoa_brand\&quot;&#x60;.  Application-defined custom attributes that are set at a global (location-independent) level. Custom attribute values are intended to store additional information about a catalog object or associations with an entity in another system. Do not use custom attributes to store any sensitive information (personally identifiable information, card details, etc.). | [optional] [beta]
**catalog_v1_ids** | [**[CatalogV1Id]**](CatalogV1Id.md) | The Connect v1 IDs for this object at each location where it is present, where they differ from the object&#39;s Connect V2 ID. The field will only be present for objects that have been created or modified by legacy APIs. | [optional] 
**present_at_all_locations** | **Boolean** | If &#x60;true&#x60;, this object is present at all locations (including future locations), except where specified in the &#x60;absent_at_location_ids&#x60; field. If &#x60;false&#x60;, this object is not present at any locations (including future locations), except where specified in the &#x60;present_at_location_ids&#x60; field. If not specified, defaults to &#x60;true&#x60;. | [optional] 
**present_at_location_ids** | **[String]** | A list of locations where the object is present, even if &#x60;present_at_all_locations&#x60; is &#x60;false&#x60;. | [optional] 
**absent_at_location_ids** | **[String]** | A list of locations where the object is not present, even if &#x60;present_at_all_locations&#x60; is &#x60;true&#x60;. | [optional] 
**image_id** | **String** | Identifies the &#x60;CatalogImage&#x60; attached to this &#x60;CatalogObject&#x60;. | [optional] 
**item_data** | [**CatalogItem**](CatalogItem.md) | Structured data for a &#x60;CatalogItem&#x60;, set for CatalogObjects of type &#x60;ITEM&#x60;. | [optional] 
**category_data** | [**CatalogCategory**](CatalogCategory.md) | Structured data for a &#x60;CatalogCategory&#x60;, set for CatalogObjects of type &#x60;CATEGORY&#x60;. | [optional] 
**item_variation_data** | [**CatalogItemVariation**](CatalogItemVariation.md) | Structured data for a &#x60;CatalogItemVariation&#x60;, set for CatalogObjects of type &#x60;ITEM_VARIATION&#x60;. | [optional] 
**tax_data** | [**CatalogTax**](CatalogTax.md) | Structured data for a &#x60;CatalogTax&#x60;, set for CatalogObjects of type &#x60;TAX&#x60;. | [optional] 
**discount_data** | [**CatalogDiscount**](CatalogDiscount.md) | Structured data for a &#x60;CatalogDiscount&#x60;, set for CatalogObjects of type &#x60;DISCOUNT&#x60;. | [optional] 
**modifier_list_data** | [**CatalogModifierList**](CatalogModifierList.md) | Structured data for a &#x60;CatalogModifierList&#x60;, set for CatalogObjects of type &#x60;MODIFIER_LIST&#x60;. | [optional] 
**modifier_data** | [**CatalogModifier**](CatalogModifier.md) | Structured data for a &#x60;CatalogModifier&#x60;, set for CatalogObjects of type &#x60;MODIFIER&#x60;. | [optional] 
**time_period_data** | [**CatalogTimePeriod**](CatalogTimePeriod.md) | Structured data for a &#x60;CatalogTimePeriod&#x60;, set for CatalogObjects of type &#x60;TIME_PERIOD&#x60;. | [optional] 
**product_set_data** | [**CatalogProductSet**](CatalogProductSet.md) | Structured data for a &#x60;CatalogProductSet&#x60;, set for CatalogObjects of type &#x60;PRODUCT_SET&#x60;. | [optional] 
**pricing_rule_data** | [**CatalogPricingRule**](CatalogPricingRule.md) | Structured data for a &#x60;CatalogPricingRule&#x60;, set for CatalogObjects of type &#x60;PRICING_RULE&#x60;. A &#x60;CatalogPricingRule&#x60; object often works with a &#x60;CatalogProductSet&#x60; object or a &#x60;CatalogTimePeriod&#x60; object. | [optional] 
**image_data** | [**CatalogImage**](CatalogImage.md) | Structured data for a &#x60;CatalogImage&#x60;, set for CatalogObjects of type &#x60;IMAGE&#x60;. | [optional] 
**measurement_unit_data** | [**CatalogMeasurementUnit**](CatalogMeasurementUnit.md) | Structured data for a &#x60;CatalogMeasurementUnit&#x60;, set for CatalogObjects of type &#x60;MEASUREMENT_UNIT&#x60;. | [optional] 
**subscription_plan_data** | [**CatalogSubscriptionPlan**](CatalogSubscriptionPlan.md) | Structured data for a &#x60;CatalogSubscriptionPlan&#x60;, set for CatalogObjects of type &#x60;SUBSCRIPTION_PLAN&#x60;. | [optional] 
**item_option_data** | [**CatalogItemOption**](CatalogItemOption.md) | Structured data for a &#x60;CatalogItemOption&#x60;, set for CatalogObjects of type &#x60;ITEM_OPTION&#x60;. | [optional] 
**item_option_value_data** | [**CatalogItemOptionValue**](CatalogItemOptionValue.md) | Structured data for a &#x60;CatalogItemOptionValue&#x60;, set for CatalogObjects of type &#x60;ITEM_OPTION_VAL&#x60;. | [optional] 
**custom_attribute_definition_data** | [**CatalogCustomAttributeDefinition**](CatalogCustomAttributeDefinition.md) | Structured data for a &#x60;CatalogCustomAttributeDefinition&#x60;, set for CatalogObjects of type &#x60;CUSTOM_ATTRIBUTE_DEFINITION&#x60;. | [optional] 
**quick_amounts_settings_data** | [**CatalogQuickAmountsSettings**](CatalogQuickAmountsSettings.md) | Structured data for a &#x60;CatalogQuickAmountsSettings&#x60;, set for CatalogObjects of type &#x60;QUICK_AMOUNTS_SETTINGS&#x60;. | [optional] 


